@@ -7,34 +7,36 @@ from jinja2 import Environment, FileSystemLoader, PackageLoader, select_autoesca
 
 from wkfs_wrapper.APIHandler import APIHandler
 from wkfs_wrapper.Utils import clean_transaction_xml
+from validator import schema_validator
+from jsonschema.exceptions import ValidationError
 
 LOGGER = logging.getLogger("root")
 
 
 class WKFSAdapter:
-    def __init__(
-        self,
-        host,
-        auth_host,
-        logging=False,
-        wkfs_config=None,
-        template_name=None,
-        timeout=None
-    ):
+    def __init__(self, host, auth_host, logging=False, wkfs_config=None, template_name=None, timeout=None):
         DEFAULT_TIMEOUT = 60
-        self._api_handler = APIHandler(host, headers={}, logging=logging, timeout=timeout if timeout else DEFAULT_TIMEOUT)
+        self._api_handler = APIHandler(
+            host, headers={}, logging=logging, timeout=timeout if timeout else DEFAULT_TIMEOUT
+        )
         self.template_name = template_name
-
-        self.wkfs_config = wkfs_config
+        try:
+            schema_validator.validate_wkfs_config(wkfs_config)
+            self.wkfs_config = wkfs_config
+        except ValidationError as e:
+            raise Exception(f"Missing Parameter in wkfs_config: {e.message}")
+        # self.validate_wkfs_config(self.wkfs_config)
         self.host = host
         self.auth_host = auth_host
 
-    def begin_docviewer_session(self, 
-            transaction_xml_payload: str,
-            callback_url: str = None,
-            package_name: str = None,
-            log_config: dict = None,
-            access_token: str = None):
+    def begin_docviewer_session(
+        self,
+        transaction_xml_payload: str,
+        callback_url: str = None,
+        package_name: str = None,
+        log_config: dict = None,
+        access_token: str = None,
+    ):
         docviewer_payload = self._generate_docviewer_payload(transaction_xml_payload, callback_url, package_name)
         headers = self._api_handler._headers
         headers["Authorization"] = f"Bearer {access_token}"
@@ -45,15 +47,13 @@ class WKFSAdapter:
             f"/DGSCoreDocViewer/api/Sessions/V2/BeginSession",
             payload=json.dumps(docviewer_payload),
             log_config=log_config,
-            headers=headers
+            headers=headers,
         )
 
         LOGGER.debug(f"begin_docviewer_session from wkfs wrapper completed")
         return json.loads(response)
-    
-    def get_docviewer_session(self, session_id, 
-            access_token: str = None,
-            log_config: dict = None):
+
+    def get_docviewer_session(self, session_id, access_token: str = None, log_config: dict = None):
         headers = self._api_handler._headers
         headers["Authorization"] = f"Bearer {access_token}"
         headers["Content-Type"] = "application/json"
@@ -62,8 +62,8 @@ class WKFSAdapter:
             "GET",
             f"/DGSCoreDocViewer/api/Sessions/{session_id}",
             log_config=log_config,
-            payload=json.dumps({"Test":"Test"}),
-            headers=headers
+            payload=json.dumps({"Test": "Test"}),
+            headers=headers,
         )
 
         LOGGER.debug(f"get_docviewer_session from wkfs wrapper completed")
@@ -86,9 +86,9 @@ class WKFSAdapter:
         transaction_data_base64 = base64_bytes.decode("utf-8")
         payload["transactionData"] = transaction_data_base64
         payload["callbackPath"] = callback_url
- 
+
         wkfs_package_name = None
-        
+
         for package in packages:
             config_package_name = package.get("name")
 
@@ -189,11 +189,11 @@ class WKFSAdapter:
             transaction_xml_payload = template.render(**data_dict)
 
             cleaned_transaction_xml_payload_bytes = clean_transaction_xml(transaction_xml_payload)
-            
+
             # file1 = open("./clean_final_code.xml", "wb")
             # file1.write(cleaned_transaction_xml_payload)
         else:
-            cleaned_transaction_xml_payload_bytes = transaction_data_xml_input.encode('utf-8')
+            cleaned_transaction_xml_payload_bytes = transaction_data_xml_input.encode("utf-8")
 
         base64_bytes = base64.b64encode(cleaned_transaction_xml_payload_bytes)
         transaction_data_base64 = base64_bytes.decode("utf-8")
@@ -207,13 +207,15 @@ class WKFSAdapter:
 
         if interface_config:
             interface_details = {}
-            interface_details["transaction_xml"] = cleaned_transaction_xml_payload_bytes.decode("utf-8").replace("\\n", "").replace("\\t", "")
+            interface_details["transaction_xml"] = (
+                cleaned_transaction_xml_payload_bytes.decode("utf-8").replace("\\n", "").replace("\\t", "")
+            )
             interface_details["updated_xml"] = None
             interface_details["changed_data_points"] = None
             interface_entry = interface_config["model"](
                 loan=interface_config["loan"],
                 interface_type=interface_config["interface_type"],
-                details = json.dumps(interface_details)
+                details=json.dumps(interface_details),
             )
             interface_entry.save()
 
@@ -227,7 +229,7 @@ class WKFSAdapter:
             f"/DocumentService/api/v1/Document/account/{account_id}/generate-synchronous",
             payload=json.dumps(payload),
             log_config=log_config,
-            headers=headers
+            headers=headers,
         )
 
         LOGGER.debug(f"generate_package from wkfs wrapper completed")
@@ -248,8 +250,6 @@ class WKFSAdapter:
         self._api_handler._host = self.auth_host
         payload = {"grant_type": grant_type, "client_id": client_id, "scope": scope}
         headers["WKFS-ClientCertificate"] = wkfs_client_certificate
-        response = self._api_handler.send_request(
-            "POST", f"/STS/connect/token", payload=payload, headers=headers
-        )
+        response = self._api_handler.send_request("POST", f"/STS/connect/token", payload=payload, headers=headers)
         LOGGER.debug(f"get_access_token from wkfs wrapper completed!")
         return response
